/* 
   HTTP URI handling
   Copyright (C) 1999-2000, Joe Orton <joe@orton.demon.co.uk>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef URI_H
#define URI_H

#ifdef HAVE_STRING_H
#include <string.h> /* for strlen in has_trailing_slash */
#endif

/* Un-escapes a URI. Returns malloc-allocated URI on success,
 * or NULL on failure (malloc failure or invalid %<HEX><HEX> sequence). */
char *uri_unescape( const char *uri );

/* Escapes the abspath segment of a URI.
 * Returns malloc-allocated string on success, or NULL on malloc failure.
 */
char *uri_abspath_escape( const char *abs_path );

char *uri_parent( const char *uri );

int uri_compare( const char *a, const char *b );

/* Returns non-zero if child is a child of parent */
int uri_childof( const char *parent, const char *child );

static inline int uri_has_trailing_slash( const char *uri ) {
    return (uri[strlen(uri)-1] == '/');
}

#endif URI_H
